@@ -161,6 +161,8 @@ class TestGauged(TestCase):
             writer.add('foobar', 250, timestamp=20000)
             writer.add('foobar', 350, timestamp=40000)
             writer.add('foobar', 70, timestamp=60000)
+        self.assertEqual(gauged.aggregate('foobar', Gauged.MIN, start=11000), 70)
+        self.assertEqual(gauged.aggregate('foobar', Gauged.MIN, start=11000, end=55000), 150)
         self.assertEqual(gauged.aggregate('foobar', Gauged.SUM), 870)
         self.assertEqual(gauged.aggregate('foobar', Gauged.MIN), 50)
         self.assertEqual(gauged.aggregate('foobar', Gauged.MAX), 350)
@@ -172,10 +174,6 @@ class TestGauged(TestCase):
         self.assertEqual(result, 150)
         result = gauged.aggregate('foobar', Gauged.PERCENTILE, percentile=90)
         self.assertEqual(result, 310)
-        result = gauged.aggregate('foobar', Gauged.FIRST)
-        self.assertEqual(result, 50)
-        result = gauged.aggregate('foobar', Gauged.LAST)
-        self.assertEqual(result, 70)
         result = gauged.aggregate('foobar', Gauged.COUNT)
         self.assertEqual(result, 5)
         start = datetime.datetime(1970, 1, 1) + datetime.timedelta(seconds=10)
@@ -265,15 +263,15 @@ class TestGauged(TestCase):
         series = gauged.aggregate_series('foobar', Gauged.SUM,
             start=10000, end=32000, interval=10000)
         self.assertListEqual(series.values, [200, 150, 40])
-        series = gauged.aggregate_series('foobar', Gauged.FIRST,
-            start=26000, end=46000, interval=10000)
-        self.assertListEqual(series.values, [40, None])
-        series = gauged.aggregate_series('foobar', Gauged.LAST,
-            start=10000, end=32000, interval=10000)
-        self.assertListEqual(series.values, [150, 30, 40])
         series = gauged.aggregate_series('foobar', Gauged.COUNT,
             start=10000, end=50000, interval=10000)
         self.assertListEqual(series.values, [2, 2, 2, 0])
+        series = gauged.aggregate_series('foobar', Gauged.MIN,
+            start=12000, end=42000, interval=10000)
+        self.assertListEqual(series.values, [120, 30, 10])
+        series = gauged.aggregate_series('foobar', Gauged.MAX,
+            start=12000, end=42000, interval=10000)
+        self.assertListEqual(series.values, [150, 40, 10])
 
     def test_aggregate_series_caching(self):
         gauged = Gauged(self.driver, block_size=10000, min_cache_interval=1)
@@ -404,6 +402,7 @@ class TestGauged(TestCase):
         self.assertEqual(gauged.aggregate('foo', Gauged.MEAN, start=10000, end=30000), 150)
         self.assertEqual(gauged.aggregate('foo', Gauged.MEAN, start=11000, end=24000), 150)
         self.assertEqual(gauged.aggregate('foo', Gauged.MEAN, start=11000, end=23000), 100)
+        self.assertEqual(gauged.aggregate('foo', Gauged.STDDEV, start=11000, end=23000), 0)
 
     def test_coercing_non_string_keys(self):
         gauged = Gauged(self.driver, resolution=1000, block_size=10000)
